#include "SDL.h"

static SDL_Joystick** joysticks;
static int num_joysticks;

int main(int argc, char* argv[]) {
  if(SDL_Init(SDL_INIT_JOYSTICK|SDL_INIT_NOPARACHUTE)) {
    fprintf(stderr, "SDL init failure: %s\n", SDL_GetError());
    return 1;
  }
  atexit(SDL_Quit);
  SDL_JoystickEventState(SDL_IGNORE);
  num_joysticks = SDL_NumJoysticks();
  if(num_joysticks == 0) {
    fprintf(stderr, "no joysticks\n");
    return 1;
  }
  joysticks = (SDL_Joystick**)malloc(sizeof(SDL_Joystick*)*num_joysticks);
  if(!joysticks) abort();
  for(int n = 0; n < num_joysticks; ++n) {
    SDL_Joystick* stick = SDL_JoystickOpen(n);
    if(!stick) {
      printf("opening %s: %s\n", n+1, SDL_JoystickName(n), SDL_GetError());
      joysticks[n] = NULL;
    }
    joysticks[n] = stick;
  }
  do {
    printf("\33[;H\33[0J");
    SDL_JoystickUpdate();
    for(int n = 0; n < num_joysticks; ++n) {
      if(joysticks[n]) {
        printf("%40s:", SDL_JoystickName(n));
        SDL_Joystick* stick = joysticks[n];
        for(int m = 0; m < SDL_JoystickNumAxes(stick); ++m) {
          printf(" %+6i", SDL_JoystickGetAxis(stick,m));
        }
        printf("\n");
      }
    }
    SDL_Delay(100);
  } while(true);
  return 0;
}
